# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/tensor/matrix_44.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&make87_messages/tensor/matrix_44.proto\x12\x17make87_messages.tensors\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x02\n\x08Matrix44\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03m00\x18\x02 \x01(\x02\x12\x0b\n\x03m01\x18\x03 \x01(\x02\x12\x0b\n\x03m02\x18\x04 \x01(\x02\x12\x0b\n\x03m03\x18\x05 \x01(\x02\x12\x0b\n\x03m10\x18\x06 \x01(\x02\x12\x0b\n\x03m11\x18\x07 \x01(\x02\x12\x0b\n\x03m12\x18\x08 \x01(\x02\x12\x0b\n\x03m13\x18\t \x01(\x02\x12\x0b\n\x03m20\x18\n \x01(\x02\x12\x0b\n\x03m21\x18\x0b \x01(\x02\x12\x0b\n\x03m22\x18\x0c \x01(\x02\x12\x0b\n\x03m23\x18\r \x01(\x02\x12\x0b\n\x03m30\x18\x0e \x01(\x02\x12\x0b\n\x03m31\x18\x0f \x01(\x02\x12\x0b\n\x03m32\x18\x10 \x01(\x02\x12\x0b\n\x03m33\x18\x11 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.tensor.matrix_44_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MATRIX44']._serialized_start=101
  _globals['_MATRIX44']._serialized_end=366
# @@protoc_insertion_point(module_scope)
