# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/geometry/box/boxes_2d.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.geometry.box import box_2d_pb2 as make87__messages_dot_geometry_dot_box_dot_box__2d__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+make87_messages/geometry/box/boxes_2d.proto\x12\x1cmake87_messages.geometry.box\x1a)make87_messages/geometry/box/box_2d.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x07\x42oxes2D\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x05\x62oxes\x18\x02 \x03(\x0b\x32#.make87_messages.geometry.box.Box2D\"\x82\x01\n\x12\x42oxes2DAxisAligned\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x05\x62oxes\x18\x02 \x03(\x0b\x32..make87_messages.geometry.box.Box2DAxisAlignedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.geometry.box.boxes_2d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOXES2D']._serialized_start=153
  _globals['_BOXES2D']._serialized_end=261
  _globals['_BOXES2DAXISALIGNED']._serialized_start=264
  _globals['_BOXES2DAXISALIGNED']._serialized_end=394
# @@protoc_insertion_point(module_scope)
