# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/image/uncompressed/image_gray.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages/image/uncompressed/image_gray.proto\x12#make87_messages.images.uncompressed\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x01\n\tImageGray\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\x44\n\x06pixels\x18\x04 \x03(\x0b\x32\x34.make87_messages.images.uncompressed.ImageGray.Pixel\x1a\x1a\n\x05Pixel\x12\x11\n\tintensity\x18\x01 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.image.uncompressed.image_gray_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_IMAGEGRAY']._serialized_start=126
  _globals['_IMAGEGRAY']._serialized_end=313
  _globals['_IMAGEGRAY_PIXEL']._serialized_start=287
  _globals['_IMAGEGRAY_PIXEL']._serialized_end=313
# @@protoc_insertion_point(module_scope)
