# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/spatial/pose/pose_3d.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from make87_messages.spatial.rotation import quaternion_pb2 as make87__messages_dot_spatial_dot_rotation_dot_quaternion__pb2
from make87_messages.spatial.translation import translation_3d_pb2 as make87__messages_dot_spatial_dot_translation_dot_translation__3d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*make87_messages/spatial/pose/pose_3d.proto\x12\x1cmake87_messages.spatial.pose\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31make87_messages/spatial/rotation/quaternion.proto\x1a\x38make87_messages/spatial/translation/translation_3d.proto\"\xc0\x01\n\x06Pose3D\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x0btranslation\x18\x02 \x01(\x0b\x32\x32.make87_messages.spatial.translation.Translation3D\x12>\n\x08rotation\x18\x03 \x01(\x0b\x32,.make87_messages.spatial.rotation.Quaternionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.spatial.pose.pose_3d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POSE3D']._serialized_start=219
  _globals['_POSE3D']._serialized_end=411
# @@protoc_insertion_point(module_scope)
